Groundhog - A general-purpose geotechnical package
====================================================

This Python package contains useful functionality for supporting automated geotechnical calculations.

Functionality for onshore and offshore geotechnical problems is included. This package is under constant
development so any request for additional functionality can always be submitted to the package author.


Installation requirements
-------------------------

groundhog is written for Python 3.7+. Downloading Anaconda3 is recommended for users not familiar with Python development.
Plotting functionality included in the package is built on plotly. The plotly package also needs to be installed and
is not included in the default Anaconda installation.

groundhog bundles a large amount of knowledge and provides it to end users through extensively documented functions. The aim of the package is as follows:

   - Improve correctness through unit-tested functions with parameter validation
   - Raise awareness on underlying test data and theories supporting engineering correlations and design formulae
   - Promoting development of open-source engineering software by the worldwide community of engineers

groundhog is developed using a set of 10 Golden rules which are reflected in the groundhog function
architecture and should also be followed by any contributors to the project.

Installation requirements
-------------------------

groundhog is written for Python 3.x. Downloading Anaconda3 is recommended for users not familiar with Python development.

Copyright (c) 2017, Bruno Stuyts
All rights reserved.

License
--------

groundhog is provided under a Creative Commons Attribution-ShareAlike 4.0 International Public License. Please check the license terms below and in the license file.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

  Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

  Redistributions in binary form must reproduce the above copyright notice, this
  list of conditions and the following disclaimer in the documentation and/or
  other materials provided with the distribution.

  Neither the name of the {organization} nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

Disclaimer
-------------

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.